@@ -39,7 +39,6 @@
 #include "fr-window.h"
 #include "file-utils.h"
 #include "fr-process.h"
-#include "mateconf-utils.h"
 #include "glib-utils.h"
 #include "main.h"
 #include "typedefs.h"
@@ -428,6 +427,7 @@ save_file_response_cb (GtkWidget  *w,
     const char *password;
     gboolean    encrypt_header;
     int         volume_size;
+    GSettings  *settings;
 
     if ((response == GTK_RESPONSE_CANCEL) || (response == GTK_RESPONSE_DELETE_EVENT)) {
         gtk_widget_destroy (data->dialog);
@@ -447,7 +447,9 @@ save_file_response_cb (GtkWidget  *w,
     encrypt_header = dlg_new_data_get_encrypt_header (data);
     volume_size = dlg_new_data_get_volume_size (data);
 
-    eel_mateconf_set_integer (PREF_BATCH_VOLUME_SIZE, volume_size);
+    settings = g_settings_new (ENGRAMPA_SCHEMA_BATCH_ADD);
+    g_settings_set_int (settings, PREF_BATCH_ADD_VOLUME_SIZE, volume_size);
+    g_object_unref (settings);
 
     fr_window_archive_save_as (data->window, path, password, encrypt_header, volume_size);
     gtk_widget_destroy (data->dialog);
@@ -723,7 +725,11 @@ void
 activate_action_view_toolbar (GtkAction *action,
                   gpointer   data)
 {
-    eel_mateconf_set_boolean (PREF_UI_TOOLBAR, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    GSettings *settings;
+
+    settings = g_settings_new (ENGRAMPA_SCHEMA_UI);
+    g_settings_set_boolean (settings, PREF_UI_VIEW_TOOLBAR, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    g_object_unref (settings);
 }
 
 
@@ -731,7 +737,11 @@ void
 activate_action_view_statusbar (GtkAction *action,
                 gpointer   data)
 {
-    eel_mateconf_set_boolean (PREF_UI_STATUSBAR, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    GSettings *settings;
+
+    settings = g_settings_new (ENGRAMPA_SCHEMA_UI);
+    g_settings_set_boolean (settings, PREF_UI_VIEW_STATUSBAR, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    g_object_unref (settings);
 }
 
 
@@ -739,7 +749,11 @@ void
 activate_action_view_folders (GtkAction *action,
                 gpointer   data)
 {
-    eel_mateconf_set_boolean (PREF_UI_FOLDERS, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    GSettings *settings;
+
+    settings = g_settings_new (ENGRAMPA_SCHEMA_UI);
+    g_settings_set_boolean (settings, PREF_UI_VIEW_FOLDERS, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+    g_object_unref (settings);
 }
 
 
