@@ -145,7 +145,11 @@ dlg_prop (FrWindow *window)
 
 	label = _gtk_builder_get_widget (data->builder, "p_size_label");
 	size = get_file_size (fr_window_get_archive_uri (window));
+#if GLIB_CHECK_VERSION (2, 30, 0)
+	s = g_format_size (size);
+#else
 	s = g_format_size_for_display (size);
+#endif
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -165,7 +169,11 @@ dlg_prop (FrWindow *window)
 	}
 
 	label = _gtk_builder_get_widget (data->builder, "p_uncomp_size_label");
+#if GLIB_CHECK_VERSION (2, 30, 0)
+	s = g_format_size (uncompressed_size);
+#else
 	s = g_format_size_for_display (uncompressed_size);
+#endif
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
